@@ -29,6 +29,7 @@ from google.cloud.exceptions import NotFound
 from google.cloud.iterator import HTTPIterator
 from google.cloud.storage._helpers import _PropertyMixin
 from google.cloud.storage._helpers import _scalar_property
+from google.cloud.storage._helpers import _validate_name
 from google.cloud.storage.acl import BucketACL
 from google.cloud.storage.acl import DefaultObjectACL
 from google.cloud.storage.blob import Blob
@@ -81,7 +82,8 @@ class Bucket(_PropertyMixin):
                    for the bucket (which requires a project).
 
     :type name: str
-    :param name: The name of the bucket.
+    :param name: The name of the bucket. Bucket names must start and end with a
+                 number or letter.
     """
 
     _MAX_OBJECTS_FOR_ITERATION = 256
@@ -106,6 +108,7 @@ class Bucket(_PropertyMixin):
     """
 
     def __init__(self, client, name=None):
+        name = _validate_name(name)
         super(Bucket, self).__init__(name=name)
         self._client = client
         self._acl = BucketACL(self)
@@ -551,7 +554,7 @@ class Bucket(_PropertyMixin):
     def etag(self):
         """Retrieve the ETag for the bucket.
 
-        See: http://tools.ietf.org/html/rfc2616#section-3.11 and
+        See: https://tools.ietf.org/html/rfc2616#section-3.11 and
              https://cloud.google.com/storage/docs/json_api/v1/buckets
 
         :rtype: str or ``NoneType``
@@ -593,7 +596,7 @@ class Bucket(_PropertyMixin):
     """Retrieve location configured for this bucket.
 
     See: https://cloud.google.com/storage/docs/json_api/v1/buckets and
-    https://cloud.google.com/storage/docs/concepts-techniques#specifyinglocations
+    https://cloud.google.com/storage/docs/bucket-locations
 
     If the property is not set locally, returns ``None``.
 
@@ -603,7 +606,7 @@ class Bucket(_PropertyMixin):
     def get_logging(self):
         """Return info about access logging for this bucket.
 
-        See: https://cloud.google.com/storage/docs/accesslogs#status
+        See: https://cloud.google.com/storage/docs/access-logs#status
 
         :rtype: dict or None
         :returns: a dict w/ keys, ``logBucket`` and ``logObjectPrefix``
@@ -615,7 +618,7 @@ class Bucket(_PropertyMixin):
     def enable_logging(self, bucket_name, object_prefix=''):
         """Enable access logging for this bucket.
 
-        See: https://cloud.google.com/storage/docs/accesslogs
+        See: https://cloud.google.com/storage/docs/access-logs
 
         :type bucket_name: str
         :param bucket_name: name of bucket in which to store access logs
@@ -629,7 +632,7 @@ class Bucket(_PropertyMixin):
     def disable_logging(self):
         """Disable access logging for this bucket.
 
-        See: https://cloud.google.com/storage/docs/accesslogs#disabling
+        See: https://cloud.google.com/storage/docs/access-logs#disabling
         """
         self._patch_property('logging', None)
 
@@ -754,7 +757,7 @@ class Bucket(_PropertyMixin):
     def configure_website(self, main_page_suffix=None, not_found_page=None):
         """Configure website-related properties.
 
-        See: https://developers.google.com/storage/docs/website-configuration
+        See: https://cloud.google.com/storage/docs/hosting-static-website
 
         .. note::
           This (apparently) only works
@@ -859,8 +862,8 @@ class Bucket(_PropertyMixin):
         For example:
 
         .. literalinclude:: storage_snippets.py
-          :start-after: [START policy_document]
-          :end-before: [END policy_document]
+            :start-after: [START policy_document]
+            :end-before: [END policy_document]
 
         .. _policy documents:
             https://cloud.google.com/storage/docs/xml-api\
