@@ -34,16 +34,18 @@ class Client(ClientWithProject):
 
     :type credentials: :class:`~google.auth.credentials.Credentials`
     :param credentials: (Optional) The OAuth2 Credentials to use for this
-                        client. If not passed (and if no ``http`` object is
+                        client. If not passed (and if no ``_http`` object is
                         passed), falls back to the default inferred from the
                         environment.
 
-    :type http: :class:`~httplib2.Http`
-    :param http: (Optional) HTTP object to make requests. Can be any object
-                 that defines ``request()`` with the same interface as
-                 :meth:`~httplib2.Http.request`. If not passed, an
-                 ``http`` object is created that is bound to the
-                 ``credentials`` for the current object.
+    :type _http: :class:`~httplib2.Http`
+    :param _http: (Optional) HTTP object to make requests. Can be any object
+                  that defines ``request()`` with the same interface as
+                  :meth:`~httplib2.Http.request`. If not passed, an
+                  ``_http`` object is created that is bound to the
+                  ``credentials`` for the current object.
+                  This parameter should be considered private, and could
+                  change in the future.
     """
 
     SCOPE = ('https://www.googleapis.com/auth/devstorage.full_control',
@@ -51,10 +53,10 @@ class Client(ClientWithProject):
              'https://www.googleapis.com/auth/devstorage.read_write')
     """The scopes required for authenticating as a Cloud Storage consumer."""
 
-    def __init__(self, project=None, credentials=None, http=None):
+    def __init__(self, project=None, credentials=None, _http=None):
         self._base_connection = None
         super(Client, self).__init__(project=project, credentials=credentials,
-                                     http=http)
+                                     _http=_http)
         self._connection = Connection(self)
         self._batch_stack = _LocalStack()
 
